import type { RepairRecordVO } from './model';

import type { ID, IDS } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  repairRecordExport = '/eims/repairRecord/export',
  repairRecordList = '/eims/repairRecord/list',
  root = '/eims/repairRecord'
}

/**
 * 查询维修记录列表
 * @param query
 * @returns {*}
 */

export function listRepairRecord(params?: any) {
  return requestClient.get<RepairRecordVO[]>(Api.repairRecordList, { params });
}

/**
 * 查询维修记录详细
 * @param RepairRecordId
 */
export function getRepairRecord(RepairRecordId: ID) {
  return requestClient.get<RepairRecordVO>(`${Api.root}/${RepairRecordId}`);
}

/**
 * 新增维修记录
 * @param data
 */
export function addRepairRecord(data: any) {
  return requestClient.postWithMsg<void>(`${Api.root}`, data);
}
/**
 * 修改维修记录
 * @param data
 */
export function updateRepairRecord(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除维修记录
 * @param RepairRecordId
 */
export function delRepairRecord(RepairRecordId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${RepairRecordId}`);
}
/**
 * 导出
 * @param
 */
export function RepairRecordExport(data: any) {
  return commonExport(Api.repairRecordExport, data);
}
